==> react-hr-component-kc-1.0.0.tgz: package/src/components/UiConfiguratorJenkins.js <==
import React from "react";
import LeftNavigationUiConfigurator from "./LeftNavigationUiConfigurator";
import { Form, Row, Col, Button } from "react-bootstrap";

function UiConfiguratorJenkins(props) {
  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Configure Jenkins</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/configure-jenkins">Configure Jenkins</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">
                  <LeftNavigationUiConfigurator />
                </div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div>
                      <Form>
                        <Form.Group
                          as={Row}
                          controlId="configureJenkinsCredentials"
                        >
                          <Form.Label column sm={2}>
                            Credentials <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              onChange={props.jenkinsCredentialsChange}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group
                          as={Row}
                          controlId="configureJenkinsServerUrl"
                        >
                          <Form.Label column sm={2}>
                            Server Url <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              onChange={props.jenkinsServerUrlChange}
                            />
                          </Col>
                        </Form.Group>
                      </Form>
                      <div className="text-right">
                        <Button
                          variant="primary"
                          onClick={props.configureJenkinsSubmit}
                        >
                          Submit
                        </Button>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UiConfiguratorJenkins;

==> react-hr-component-kc-1.0.1.tgz: package/src/components/UiConfiguratorJenkins.js <==
import React, { useState, useEffect } from "react";
import LeftNavigationUiConfigurator from "./LeftNavigationUiConfigurator";
import { Form, Row, Col, Button } from "react-bootstrap";

function UiConfiguratorJenkins(props) {
  const [jenkinsCredential, setJenkinsCredential] = useState("");
  const [jenkinsServerUrl, setJenkinsServerUrl] = useState("");

  const jenkinsCredentialsChangeHandler = (event) => {
    setJenkinsCredential(event.target.value);
    console.log(jenkinsCredential);
  };

  const jenkinsServerUrlChangeHandler = (event) => {
    setJenkinsServerUrl(event.target.value);
    console.log(jenkinsServerUrl);
  };

  // const configureJenkinsSubmitHandler = () => {
  //   console.log("Jenkins form submitted");
  // };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Configure Jenkins</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/configure-jenkins">Configure Jenkins</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">
                  <LeftNavigationUiConfigurator />
                </div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div>
                      <Form>
                        <Form.Group
                          as={Row}
                          controlId="configureJenkinsCredentials"
                        >
                          <Form.Label column sm={2}>
                            Credentials <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              // onChange={props.jenkinsCredentialsChange}
                              onChange={jenkinsCredentialsChangeHandler}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group
                          as={Row}
                          controlId="configureJenkinsServerUrl"
                        >
                          <Form.Label column sm={2}>
                            Server Url <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              // onChange={props.jenkinsServerUrlChange}
                              onChange={jenkinsServerUrlChangeHandler}
                            />
                          </Col>
                        </Form.Group>
                      </Form>
                      <div className="text-right">
                        <Button
                          variant="primary"
                          onClick={props.configureJenkinsSubmit}
                        >
                          Submit
                        </Button>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UiConfiguratorJenkins;
